package PDF::Builder::Resource::Font::CoreFont::georgiabolditalic;

use strict;
use warnings;

our $VERSION = '3.027'; # VERSION
our $LAST_UPDATE = '3.027'; # manually update whenever code is changed

=head1 NAME

PDF::Builder::Resource::Font::CoreFont::georgiabolditalic - Font-specific information for bold weight + italic Georgia font

I<Not> a standard PDF core font

=cut

sub data { return {
    'fontname' => 'Georgia,BoldItalic',
    'type' => 'TrueType',
    'apiname' => 'GeBoIt',
    'ascender' => '916',
    'capheight' => '692',
    'descender' => '-219',
    'isfixedpitch' => '0',
    'issymbol' => '0',
    'italicangle' => '-13',
    'underlineposition' => '-181',
    'underlinethickness' => '120',
    'xheight' => '495',
    'firstchar' => '32',
    'lastchar' => '255',
    'flags' => '262242',
    'char' => [ # DEF. ENCODING GLYPH TABLE
        '.notdef',                               # C+0x00 # U+0x0000
        '.notdef',                               # C+0x01 # U+0x0000
        '.notdef',                               # C+0x02 # U+0x0000
        '.notdef',                               # C+0x03 # U+0x0000
        '.notdef',                               # C+0x04 # U+0x0000
        '.notdef',                               # C+0x05 # U+0x0000
        '.notdef',                               # C+0x06 # U+0x0000
        '.notdef',                               # C+0x07 # U+0x0000
        '.notdef',                               # C+0x08 # U+0x0000
        '.notdef',                               # C+0x09 # U+0x0000
        '.notdef',                               # C+0x0A # U+0x0000
        '.notdef',                               # C+0x0B # U+0x0000
        '.notdef',                               # C+0x0C # U+0x0000
        '.notdef',                               # C+0x0D # U+0x0000
        '.notdef',                               # C+0x0E # U+0x0000
        '.notdef',                               # C+0x0F # U+0x0000
        '.notdef',                               # C+0x10 # U+0x0000
        '.notdef',                               # C+0x11 # U+0x0000
        '.notdef',                               # C+0x12 # U+0x0000
        '.notdef',                               # C+0x13 # U+0x0000
        '.notdef',                               # C+0x14 # U+0x0000
        '.notdef',                               # C+0x15 # U+0x0000
        '.notdef',                               # C+0x16 # U+0x0000
        '.notdef',                               # C+0x17 # U+0x0000
        '.notdef',                               # C+0x18 # U+0x0000
        '.notdef',                               # C+0x19 # U+0x0000
        '.notdef',                               # C+0x1A # U+0x0000
        '.notdef',                               # C+0x1B # U+0x0000
        '.notdef',                               # C+0x1C # U+0x0000
        '.notdef',                               # C+0x1D # U+0x0000
        '.notdef',                               # C+0x1E # U+0x0000
        '.notdef',                               # C+0x1F # U+0x0000
        'space',                                 # C+0x20 # U+0x0020
        'exclam',                                # C+0x21 # U+0x0021
        'quotedbl',                              # C+0x22 # U+0x0022
        'numbersign',                            # C+0x23 # U+0x0023
        'dollar',                                # C+0x24 # U+0x0024
        'percent',                               # C+0x25 # U+0x0025
        'ampersand',                             # C+0x26 # U+0x0026
        'quotesingle',                           # C+0x27 # U+0x0027
        'parenleft',                             # C+0x28 # U+0x0028
        'parenright',                            # C+0x29 # U+0x0029
        'asterisk',                              # C+0x2A # U+0x002A
        'plus',                                  # C+0x2B # U+0x002B
        'comma',                                 # C+0x2C # U+0x002C
        'hyphen',                                # C+0x2D # U+0x002D
        'period',                                # C+0x2E # U+0x002E
        'slash',                                 # C+0x2F # U+0x002F
        'zero',                                  # C+0x30 # U+0x0030
        'one',                                   # C+0x31 # U+0x0031
        'two',                                   # C+0x32 # U+0x0032
        'three',                                 # C+0x33 # U+0x0033
        'four',                                  # C+0x34 # U+0x0034
        'five',                                  # C+0x35 # U+0x0035
        'six',                                   # C+0x36 # U+0x0036
        'seven',                                 # C+0x37 # U+0x0037
        'eight',                                 # C+0x38 # U+0x0038
        'nine',                                  # C+0x39 # U+0x0039
        'colon',                                 # C+0x3A # U+0x003A
        'semicolon',                             # C+0x3B # U+0x003B
        'less',                                  # C+0x3C # U+0x003C
        'equal',                                 # C+0x3D # U+0x003D
        'greater',                               # C+0x3E # U+0x003E
        'question',                              # C+0x3F # U+0x003F
        'at',                                    # C+0x40 # U+0x0040
        'A',                                     # C+0x41 # U+0x0041
        'B',                                     # C+0x42 # U+0x0042
        'C',                                     # C+0x43 # U+0x0043
        'D',                                     # C+0x44 # U+0x0044
        'E',                                     # C+0x45 # U+0x0045
        'F',                                     # C+0x46 # U+0x0046
        'G',                                     # C+0x47 # U+0x0047
        'H',                                     # C+0x48 # U+0x0048
        'I',                                     # C+0x49 # U+0x0049
        'J',                                     # C+0x4A # U+0x004A
        'K',                                     # C+0x4B # U+0x004B
        'L',                                     # C+0x4C # U+0x004C
        'M',                                     # C+0x4D # U+0x004D
        'N',                                     # C+0x4E # U+0x004E
        'O',                                     # C+0x4F # U+0x004F
        'P',                                     # C+0x50 # U+0x0050
        'Q',                                     # C+0x51 # U+0x0051
        'R',                                     # C+0x52 # U+0x0052
        'S',                                     # C+0x53 # U+0x0053
        'T',                                     # C+0x54 # U+0x0054
        'U',                                     # C+0x55 # U+0x0055
        'V',                                     # C+0x56 # U+0x0056
        'W',                                     # C+0x57 # U+0x0057
        'X',                                     # C+0x58 # U+0x0058
        'Y',                                     # C+0x59 # U+0x0059
        'Z',                                     # C+0x5A # U+0x005A
        'bracketleft',                           # C+0x5B # U+0x005B
        'backslash',                             # C+0x5C # U+0x005C
        'bracketright',                          # C+0x5D # U+0x005D
        'asciicircum',                           # C+0x5E # U+0x005E
        'underscore',                            # C+0x5F # U+0x005F
        'grave',                                 # C+0x60 # U+0x0060
        'a',                                     # C+0x61 # U+0x0061
        'b',                                     # C+0x62 # U+0x0062
        'c',                                     # C+0x63 # U+0x0063
        'd',                                     # C+0x64 # U+0x0064
        'e',                                     # C+0x65 # U+0x0065
        'f',                                     # C+0x66 # U+0x0066
        'g',                                     # C+0x67 # U+0x0067
        'h',                                     # C+0x68 # U+0x0068
        'i',                                     # C+0x69 # U+0x0069
        'j',                                     # C+0x6A # U+0x006A
        'k',                                     # C+0x6B # U+0x006B
        'l',                                     # C+0x6C # U+0x006C
        'm',                                     # C+0x6D # U+0x006D
        'n',                                     # C+0x6E # U+0x006E
        'o',                                     # C+0x6F # U+0x006F
        'p',                                     # C+0x70 # U+0x0070
        'q',                                     # C+0x71 # U+0x0071
        'r',                                     # C+0x72 # U+0x0072
        's',                                     # C+0x73 # U+0x0073
        't',                                     # C+0x74 # U+0x0074
        'u',                                     # C+0x75 # U+0x0075
        'v',                                     # C+0x76 # U+0x0076
        'w',                                     # C+0x77 # U+0x0077
        'x',                                     # C+0x78 # U+0x0078
        'y',                                     # C+0x79 # U+0x0079
        'z',                                     # C+0x7A # U+0x007A
        'braceleft',                             # C+0x7B # U+0x007B
        'bar',                                   # C+0x7C # U+0x007C
        'braceright',                            # C+0x7D # U+0x007D
        'asciitilde',                            # C+0x7E # U+0x007E
        'bullet',                                # C+0x7F # U+0x2022
        'Euro',                                  # C+0x80 # U+0x20AC
        'bullet',                                # C+0x81 # U+0x2022
        'quotesinglbase',                        # C+0x82 # U+0x201A
        'florin',                                # C+0x83 # U+0x0192
        'quotedblbase',                          # C+0x84 # U+0x201E
        'ellipsis',                              # C+0x85 # U+0x2026
        'dagger',                                # C+0x86 # U+0x2020
        'daggerdbl',                             # C+0x87 # U+0x2021
        'circumflex',                            # C+0x88 # U+0x02C6
        'perthousand',                           # C+0x89 # U+0x2030
        'Scaron',                                # C+0x8A # U+0x0160
        'guilsinglleft',                         # C+0x8B # U+0x2039
        'OE',                                    # C+0x8C # U+0x0152
        'bullet',                                # C+0x8D # U+0x2022
        'Zcaron',                                # C+0x8E # U+0x017D
        'bullet',                                # C+0x8F # U+0x2022
        'bullet',                                # C+0x90 # U+0x2022
        'quoteleft',                             # C+0x91 # U+0x2018
        'quoteright',                            # C+0x92 # U+0x2019
        'quotedblleft',                          # C+0x93 # U+0x201C
        'quotedblright',                         # C+0x94 # U+0x201D
        'bullet',                                # C+0x95 # U+0x2022
        'endash',                                # C+0x96 # U+0x2013
        'emdash',                                # C+0x97 # U+0x2014
        'tilde',                                 # C+0x98 # U+0x02DC
        'trademark',                             # C+0x99 # U+0x2122
        'scaron',                                # C+0x9A # U+0x0161
        'guilsinglright',                        # C+0x9B # U+0x203A
        'oe',                                    # C+0x9C # U+0x0153
        'bullet',                                # C+0x9D # U+0x2022
        'zcaron',                                # C+0x9E # U+0x017E
        'Ydieresis',                             # C+0x9F # U+0x0178
        'space',                                 # C+0xA0 # U+0x0020
        'exclamdown',                            # C+0xA1 # U+0x00A1
        'cent',                                  # C+0xA2 # U+0x00A2
        'sterling',                              # C+0xA3 # U+0x00A3
        'currency',                              # C+0xA4 # U+0x00A4
        'yen',                                   # C+0xA5 # U+0x00A5
        'brokenbar',                             # C+0xA6 # U+0x00A6
        'section',                               # C+0xA7 # U+0x00A7
        'dieresis',                              # C+0xA8 # U+0x00A8
        'copyright',                             # C+0xA9 # U+0x00A9
        'ordfeminine',                           # C+0xAA # U+0x00AA
        'guillemotleft',                         # C+0xAB # U+0x00AB
        'logicalnot',                            # C+0xAC # U+0x00AC
        'hyphen',                                # C+0xAD # U+0x002D
        'registered',                            # C+0xAE # U+0x00AE
        'macron',                                # C+0xAF # U+0x00AF
        'degree',                                # C+0xB0 # U+0x00B0
        'plusminus',                             # C+0xB1 # U+0x00B1
        'twosuperior',                           # C+0xB2 # U+0x00B2
        'threesuperior',                         # C+0xB3 # U+0x00B3
        'acute',                                 # C+0xB4 # U+0x00B4
        'mu',                                    # C+0xB5 # U+0x00B5
        'paragraph',                             # C+0xB6 # U+0x00B6
        'periodcentered',                        # C+0xB7 # U+0x00B7
        'cedilla',                               # C+0xB8 # U+0x00B8
        'onesuperior',                           # C+0xB9 # U+0x00B9
        'ordmasculine',                          # C+0xBA # U+0x00BA
        'guillemotright',                        # C+0xBB # U+0x00BB
        'onequarter',                            # C+0xBC # U+0x00BC
        'onehalf',                               # C+0xBD # U+0x00BD
        'threequarters',                         # C+0xBE # U+0x00BE
        'questiondown',                          # C+0xBF # U+0x00BF
        'Agrave',                                # C+0xC0 # U+0x00C0
        'Aacute',                                # C+0xC1 # U+0x00C1
        'Acircumflex',                           # C+0xC2 # U+0x00C2
        'Atilde',                                # C+0xC3 # U+0x00C3
        'Adieresis',                             # C+0xC4 # U+0x00C4
        'Aring',                                 # C+0xC5 # U+0x00C5
        'AE',                                    # C+0xC6 # U+0x00C6
        'Ccedilla',                              # C+0xC7 # U+0x00C7
        'Egrave',                                # C+0xC8 # U+0x00C8
        'Eacute',                                # C+0xC9 # U+0x00C9
        'Ecircumflex',                           # C+0xCA # U+0x00CA
        'Edieresis',                             # C+0xCB # U+0x00CB
        'Igrave',                                # C+0xCC # U+0x00CC
        'Iacute',                                # C+0xCD # U+0x00CD
        'Icircumflex',                           # C+0xCE # U+0x00CE
        'Idieresis',                             # C+0xCF # U+0x00CF
        'Eth',                                   # C+0xD0 # U+0x00D0
        'Ntilde',                                # C+0xD1 # U+0x00D1
        'Ograve',                                # C+0xD2 # U+0x00D2
        'Oacute',                                # C+0xD3 # U+0x00D3
        'Ocircumflex',                           # C+0xD4 # U+0x00D4
        'Otilde',                                # C+0xD5 # U+0x00D5
        'Odieresis',                             # C+0xD6 # U+0x00D6
        'multiply',                              # C+0xD7 # U+0x00D7
        'Oslash',                                # C+0xD8 # U+0x00D8
        'Ugrave',                                # C+0xD9 # U+0x00D9
        'Uacute',                                # C+0xDA # U+0x00DA
        'Ucircumflex',                           # C+0xDB # U+0x00DB
        'Udieresis',                             # C+0xDC # U+0x00DC
        'Yacute',                                # C+0xDD # U+0x00DD
        'Thorn',                                 # C+0xDE # U+0x00DE
        'germandbls',                            # C+0xDF # U+0x00DF
        'agrave',                                # C+0xE0 # U+0x00E0
        'aacute',                                # C+0xE1 # U+0x00E1
        'acircumflex',                           # C+0xE2 # U+0x00E2
        'atilde',                                # C+0xE3 # U+0x00E3
        'adieresis',                             # C+0xE4 # U+0x00E4
        'aring',                                 # C+0xE5 # U+0x00E5
        'ae',                                    # C+0xE6 # U+0x00E6
        'ccedilla',                              # C+0xE7 # U+0x00E7
        'egrave',                                # C+0xE8 # U+0x00E8
        'eacute',                                # C+0xE9 # U+0x00E9
        'ecircumflex',                           # C+0xEA # U+0x00EA
        'edieresis',                             # C+0xEB # U+0x00EB
        'igrave',                                # C+0xEC # U+0x00EC
        'iacute',                                # C+0xED # U+0x00ED
        'icircumflex',                           # C+0xEE # U+0x00EE
        'idieresis',                             # C+0xEF # U+0x00EF
        'eth',                                   # C+0xF0 # U+0x00F0
        'ntilde',                                # C+0xF1 # U+0x00F1
        'ograve',                                # C+0xF2 # U+0x00F2
        'oacute',                                # C+0xF3 # U+0x00F3
        'ocircumflex',                           # C+0xF4 # U+0x00F4
        'otilde',                                # C+0xF5 # U+0x00F5
        'odieresis',                             # C+0xF6 # U+0x00F6
        'divide',                                # C+0xF7 # U+0x00F7
        'oslash',                                # C+0xF8 # U+0x00F8
        'ugrave',                                # C+0xF9 # U+0x00F9
        'uacute',                                # C+0xFA # U+0x00FA
        'ucircumflex',                           # C+0xFB # U+0x00FB
        'udieresis',                             # C+0xFC # U+0x00FC
        'yacute',                                # C+0xFD # U+0x00FD
        'thorn',                                 # C+0xFE # U+0x00FE
        'ydieresis',                             # C+0xFF # U+0x00FF
    ], # DEF. ENCODING GLYPH TABLE
    'fontbbox' => [ -242, -216, 1354, 914 ],
# source: \Windows\Fonts\georgiaz.ttf
# font underline position = -181
# CIDs 0 .. 863 to be output
# fontbbox = (-242 -303 1354 994)
    'wx' => { # HORIZ. WIDTH TABLE
        'A'       => 758,
        'AE'       => 1074,
        'AEacute'       => 1074,
        'Aacute'       => 758,
        'Abreve'       => 758,
        'Acircumflex'       => 758,
        'Adieresis'       => 758,
        'Agrave'       => 758,
        'Alpha'       => 758,
        'Alphatonos'       => 758,
        'Amacron'       => 758,
        'Aogonek'       => 758,
        'Aring'       => 758,
        'Aringacute'       => 758,
        'Atilde'       => 758,
        'B'       => 759,
        'Beta'       => 759,
        'C'       => 715,
        'Cacute'       => 715,
        'Ccaron'       => 715,
        'Ccedilla'       => 715,
        'Ccircumflex'       => 715,
        'Cdotaccent'       => 715,
        'Chi'       => 802,
        'D'       => 833,
        'Dcaron'       => 833,
        'Dcroat'       => 833,
        'Delta'       => 743,
        'E'       => 721,
        'Eacute'       => 721,
        'Ebreve'       => 721,
        'Ecaron'       => 721,
        'Ecircumflex'       => 721,
        'Edieresis'       => 721,
        'Edotaccent'       => 721,
        'Egrave'       => 721,
        'Emacron'       => 721,
        'Eng'       => 829,
        'Eogonek'       => 721,
        'Epsilon'       => 721,
        'Epsilontonos'       => 880,
        'Eta'       => 913,
        'Etatonos'       => 1072,
        'Eth'       => 833,
        'Euro'       => 715,
        'F'       => 671,
        'G'       => 807,
        'Gamma'       => 655,
        'Gbreve'       => 807,
        'Gcircumflex'       => 807,
        'Gcommaaccent'       => 807,
        'Gdotaccent'       => 807,
        'H'       => 913,
        'H18533'       => 604,
        'H18543'       => 354,
        'H18551'       => 354,
        'H22073'       => 604,
        'Hbar'       => 913,
        'Hcircumflex'       => 913,
        'I'       => 450,
        'IJ'       => 996,
        'Iacute'       => 445,
        'Ibreve'       => 450,
        'Icircumflex'       => 445,
        'Idieresis'       => 450,
        'Idotaccent'       => 450,
        'Igrave'       => 445,
        'Imacron'       => 450,
        'Iogonek'       => 450,
        'Iota'       => 450,
        'Iotadieresis'       => 450,
        'Iotatonos'       => 609,
        'Itilde'       => 450,
        'J'       => 595,
        'Jcircumflex'       => 595,
        'K'       => 816,
        'Kappa'       => 816,
        'Kcommaaccent'       => 816,
        'L'       => 685,
        'Lacute'       => 685,
        'Lambda'       => 752,
        'Lcaron'       => 685,
        'Lcommaaccent'       => 685,
        'Ldot'       => 685,
        'Lslash'       => 685,
        'M'       => 1033,
        'Mu'       => 1033,
        'N'       => 829,
        'Nacute'       => 829,
        'Ncaron'       => 829,
        'Ncommaaccent'       => 829,
        'Ntilde'       => 829,
        'Nu'       => 829,
        'O'       => 819,
        'OE'       => 1105,
        'Oacute'       => 819,
        'Obreve'       => 819,
        'Ocircumflex'       => 819,
        'Odieresis'       => 819,
        'Ograve'       => 819,
        'Ohungarumlaut'       => 819,
        'Omacron'       => 819,
        'Omega'       => 877,
        'Omegatonos'       => 960,
        'Omicron'       => 819,
        'Omicrontonos'       => 922,
        'Oslash'       => 819,
        'Oslashacute'       => 819,
        'Otilde'       => 819,
        'P'       => 706,
        'Phi'       => 911,
        'Pi'       => 900,
        'Psi'       => 1011,
        'Q'       => 819,
        'R'       => 797,
        'Racute'       => 797,
        'Rcaron'       => 797,
        'Rcommaaccent'       => 797,
        'Rho'       => 706,
        'S'       => 652,
        'SF010000'       => 708,
        'SF020000'       => 708,
        'SF030000'       => 708,
        'SF040000'       => 708,
        'SF100000'       => 708,
        'SF110000'       => 708,
        'Sacute'       => 652,
        'Scaron'       => 652,
        'Scedilla'       => 652,
        'Scircumflex'       => 652,
        'Scommaaccent'       => 652,
        'Sigma'       => 679,
        'T'       => 684,
        'Tau'       => 684,
        'Tbar'       => 684,
        'Tcaron'       => 684,
        'Tcedilla'       => 684,
        'Tcommaaccent'       => 684,
        'Theta'       => 822,
        'Thorn'       => 708,
        'U'       => 833,
        'Uacute'       => 833,
        'Ubreve'       => 833,
        'Ucircumflex'       => 833,
        'Udieresis'       => 833,
        'Ugrave'       => 833,
        'Uhungarumlaut'       => 833,
        'Umacron'       => 833,
        'Uogonek'       => 833,
        'Upsilon'       => 731,
        'Upsilondieresis'       => 731,
        'Upsilontonos'       => 935,
        'Uring'       => 833,
        'Utilde'       => 833,
        'V'       => 762,
        'W'       => 1126,
        'Wacute'       => 1126,
        'Wcircumflex'       => 1126,
        'Wdieresis'       => 1126,
        'Wgrave'       => 1126,
        'X'       => 802,
        'Xi'       => 766,
        'Y'       => 731,
        'Yacute'       => 731,
        'Ycircumflex'       => 731,
        'Ydieresis'       => 731,
        'Ygrave'       => 731,
        'Z'       => 689,
        'Zacute'       => 689,
        'Zcaron'       => 689,
        'Zdotaccent'       => 689,
        'Zeta'       => 689,
        'a'       => 660,
        'aacute'       => 660,
        'abreve'       => 660,
        'acircumflex'       => 660,
        'acute'       => 500,
        'acutecomb'       => 500,
        'adieresis'       => 660,
        'ae'       => 856,
        'aeacute'       => 856,
        'afii00208'       => 927,
        'afii10017'       => 758,
        'afii10018'       => 743,
        'afii10019'       => 759,
        'afii10020'       => 655,
        'afii10021'       => 800,
        'afii10022'       => 721,
        'afii10023'       => 721,
        'afii10024'       => 1127,
        'afii10025'       => 684,
        'afii10026'       => 921,
        'afii10027'       => 921,
        'afii10028'       => 794,
        'afii10029'       => 832,
        'afii10030'       => 1033,
        'afii10031'       => 913,
        'afii10032'       => 819,
        'afii10033'       => 900,
        'afii10034'       => 706,
        'afii10035'       => 715,
        'afii10036'       => 684,
        'afii10037'       => 712,
        'afii10038'       => 911,
        'afii10039'       => 802,
        'afii10040'       => 901,
        'afii10041'       => 832,
        'afii10042'       => 1283,
        'afii10043'       => 1284,
        'afii10044'       => 855,
        'afii10045'       => 1106,
        'afii10046'       => 726,
        'afii10047'       => 729,
        'afii10048'       => 1183,
        'afii10049'       => 803,
        'afii10050'       => 645,
        'afii10051'       => 883,
        'afii10052'       => 655,
        'afii10053'       => 730,
        'afii10054'       => 652,
        'afii10055'       => 450,
        'afii10056'       => 450,
        'afii10057'       => 595,
        'afii10058'       => 1112,
        'afii10059'       => 1184,
        'afii10060'       => 935,
        'afii10061'       => 794,
        'afii10062'       => 712,
        'afii10065'       => 660,
        'afii10066'       => 627,
        'afii10067'       => 598,
        'afii10068'       => 520,
        'afii10069'       => 620,
        'afii10070'       => 557,
        'afii10071'       => 557,
        'afii10072'       => 1091,
        'afii10073'       => 539,
        'afii10074'       => 685,
        'afii10075'       => 685,
        'afii10076'       => 646,
        'afii10077'       => 647,
        'afii10078'       => 875,
        'afii10079'       => 688,
        'afii10080'       => 635,
        'afii10081'       => 689,
        'afii10082'       => 662,
        'afii10083'       => 535,
        'afii10084'       => 1001,
        'afii10085'       => 669,
        'afii10086'       => 886,
        'afii10087'       => 583,
        'afii10088'       => 685,
        'afii10089'       => 656,
        'afii10090'       => 982,
        'afii10091'       => 982,
        'afii10092'       => 668,
        'afii10093'       => 925,
        'afii10094'       => 614,
        'afii10095'       => 539,
        'afii10096'       => 919,
        'afii10097'       => 642,
        'afii10098'       => 510,
        'afii10099'       => 663,
        'afii10100'       => 520,
        'afii10101'       => 535,
        'afii10102'       => 517,
        'afii10103'       => 365,
        'afii10104'       => 365,
        'afii10105'       => 364,
        'afii10106'       => 895,
        'afii10107'       => 937,
        'afii10108'       => 675,
        'afii10109'       => 646,
        'afii10110'       => 669,
        'afii10145'       => 901,
        'afii10193'       => 685,
        'afii61248'       => 879,
        'afii61289'       => 323,
        'afii61352'       => 1401,
        'agrave'       => 660,
        'alpha'       => 679,
        'alphatonos'       => 679,
        'amacron'       => 660,
        'ampersand'       => 799,
        'anoteleia'       => 367,
        'aogonek'       => 660,
        'approxequal'       => 703,
        'aring'       => 660,
        'aringacute'       => 660,
        'asciicircum'       => 703,
        'asciitilde'       => 703,
        'asterisk'       => 481,
        'at'       => 966,
        'atilde'       => 660,
        'b'       => 648,
        'backslash'       => 471,
        'bar'       => 387,
        'beta'       => 658,
        'braceleft'       => 500,
        'braceright'       => 500,
        'bracketleft'       => 446,
        'bracketright'       => 446,
        'breve'       => 500,
        'brevecmb'       => 500,
        'brokenbar'       => 387,
        'bullet'       => 437,
        'c'       => 535,
        'cacute'       => 535,
        'caron'       => 500,
        'caroncmb'       => 500,
        'ccaron'       => 535,
        'ccedilla'       => 535,
        'ccircumflex'       => 535,
        'cdotaccent'       => 535,
        'cedilla'       => 500,
        'cent'       => 605,
        'chi'       => 566,
        'circumflex'       => 500,
        'circumflexcmb'       => 500,
        'colon'       => 367,
        'colontriangularhalfmod'       => 500,
        'comma'       => 328,
        'copyright'       => 941,
        'currency'       => 703,
        'd'       => 662,
        'dagger'       => 481,
        'daggerdbl'       => 481,
        'dcaron'       => 825,
        'dcroat'       => 662,
        'degree'       => 419,
        'delta'       => 635,
        'dieresis'       => 500,
        'dieresiscmb'       => 500,
        'dieresistonos'       => 500,
        'divide'       => 703,
        'dollar'       => 640,
        'dotaccent'       => 500,
        'dotlessi'       => 365,
        'dotlessj'       => 365,
        'e'       => 557,
        'eacute'       => 557,
        'ebreve'       => 557,
        'ecaron'       => 557,
        'ecircumflex'       => 557,
        'edieresis'       => 557,
        'edotaccent'       => 557,
        'egrave'       => 557,
        'eight'       => 676,
        'eightinferior'       => 551,
        'eightsuperior'       => 551,
        'ellipsis'       => 941,
        'emacron'       => 557,
        'emdash'       => 927,
        'endash'       => 703,
        'eng'       => 677,
        'eogonek'       => 557,
        'epsilon'       => 535,
        'epsilontonos'       => 535,
        'equal'       => 703,
        'estimated'       => 649,
        'eta'       => 665,
        'etatonos'       => 665,
        'eth'       => 637,
        'exclam'       => 376,
        'exclamdbl'       => 664,
        'exclamdown'       => 376,
        'f'       => 380,
        'ff'       => 717,
        'ffi'       => 1039,
        'ffl'       => 1057,
        'fi'       => 701,
        'five'       => 599,
        'fiveeighths'       => 1071,
        'fiveinferior'       => 551,
        'fivesuperior'       => 551,
        'fl'       => 720,
        'florin'       => 579,
        'four'       => 649,
        'fourinferior'       => 551,
        'foursuperior'       => 551,
        'fraction'       => 94,
        'franc'       => 689,
        'g'       => 649,
        'gamma'       => 570,
        'gbreve'       => 649,
        'gcircumflex'       => 649,
        'gcommaaccent'       => 649,
        'gdotaccent'       => 649,
        'germandbls'       => 655,
        'grave'       => 500,
        'gravecomb'       => 500,
        'greater'       => 703,
        'greaterequal'       => 703,
        'guillemotleft'       => 610,
        'guillemotright'       => 610,
        'guilsinglleft'       => 395,
        'guilsinglright'       => 395,
        'h'       => 675,
        'hbar'       => 675,
        'hcircumflex'       => 675,
        'hungarumlaut'       => 500,
        'hungarumlautcmb'       => 500,
        'hyphen'       => 378,
        'i'       => 365,
        'iacute'       => 365,
        'ibreve'       => 365,
        'icircumflex'       => 365,
        'idieresis'       => 365,
        'igrave'       => 365,
        'ij'       => 682,
        'imacron'       => 365,
        'infinity'       => 798,
        'integral'       => 627,
        'iogonek'       => 365,
        'iota'       => 345,
        'iotadieresis'       => 345,
        'iotadieresistonos'       => 345,
        'iotatonos'       => 345,
        'itilde'       => 365,
        'j'       => 364,
        'jcircumflex'       => 364,
        'k'       => 641,
        'kappa'       => 655,
        'kcommaaccent'       => 641,
        'kgreenlandic'       => 655,
        'l'       => 354,
        'lacute'       => 354,
        'lambda'       => 527,
        'lcaron'       => 511,
        'lcommaaccent'       => 354,
        'ldot'       => 546,
        'less'       => 703,
        'lessequal'       => 703,
        'lira'       => 689,
        'logicalnot'       => 703,
        'longs'       => 361,
        'lozenge'       => 717,
        'lslash'       => 354,
        'm'       => 1001,
        'macron'       => 703,
        'minus'       => 703,
        'minute'       => 321,
        'mu'       => 669,
        'multiply'       => 703,
        'musicalnote'       => 500,
        'n'       => 689,
        'nacute'       => 689,
        'napostrophe'       => 832,
        'ncaron'       => 689,
        'ncommaaccent'       => 689,
        'nine'       => 647,
        'nineinferior'       => 551,
        'ninesuperior'       => 551,
        'notequal'       => 703,
        'nsuperior'       => 551,
        'ntilde'       => 689,
        'nu'       => 561,
        'numbersign'       => 703,
        'o'       => 635,
        'oacute'       => 635,
        'obreve'       => 635,
        'ocircumflex'       => 635,
        'odieresis'       => 635,
        'oe'       => 932,
        'ogonek'       => 500,
        'ograve'       => 635,
        'ohungarumlaut'       => 635,
        'omacron'       => 635,
        'omega'       => 804,
        'omegatonos'       => 804,
        'omicron'       => 635,
        'omicrontonos'       => 635,
        'one'       => 489,
        'oneeighth'       => 1071,
        'onehalf'       => 1071,
        'oneinferior'       => 551,
        'onequarter'       => 1071,
        'onesuperior'       => 551,
        'openbullet'       => 354,
        'ordfeminine'       => 551,
        'ordmasculine'       => 551,
        'oslash'       => 635,
        'oslashacute'       => 635,
        'otilde'       => 635,
        'overline'       => 703,
        'p'       => 662,
        'paragraph'       => 622,
        'parenleft'       => 446,
        'parenright'       => 446,
        'partialdiff'       => 646,
        'percent'       => 879,
        'period'       => 328,
        'periodcentered'       => 337,
        'perthousand'       => 1316,
        'peseta'       => 1355,
        'phi'       => 830,
        'pi'       => 659,
        'plus'       => 703,
        'plusminus'       => 703,
        'product'       => 932,
        'psi'       => 857,
        'q'       => 649,
        'question'       => 548,
        'questiondown'       => 548,
        'questiongreek'       => 367,
        'quotedbl'       => 509,
        'quotedblbase'       => 519,
        'quotedblleft'       => 519,
        'quotedblright'       => 519,
        'quoteleft'       => 268,
        'quotereversed'       => 268,
        'quoteright'       => 268,
        'quotesinglbase'       => 268,
        'quotesingle'       => 269,
        'r'       => 533,
        'racute'       => 533,
        'radical'       => 703,
        'rcaron'       => 533,
        'rcommaaccent'       => 533,
        'registered'       => 941,
        'rho'       => 645,
        'ring'       => 500,
        's'       => 517,
        'sacute'       => 517,
        'scaron'       => 517,
        'scedilla'       => 517,
        'scircumflex'       => 517,
        'scommaaccent'       => 517,
        'second'       => 532,
        'section'       => 563,
        'seven'       => 566,
        'seveneighths'       => 1071,
        'seveninferior'       => 551,
        'sevensuperior'       => 551,
        'sigma'       => 669,
        'sigma1'       => 513,
        'six'       => 647,
        'sixinferior'       => 551,
        'sixsuperior'       => 551,
        'slash'       => 471,
        'space'       => 253,
        'sterling'       => 689,
        'summation'       => 729,
        't'       => 416,
        'tau'       => 485,
        'tbar'       => 416,
        'tcaron'       => 416,
        'tcedilla'       => 416,
        'tcommaaccent'       => 416,
        'theta'       => 640,
        'thorn'       => 647,
        'three'       => 624,
        'threeeighths'       => 1071,
        'threeinferior'       => 551,
        'threequarters'       => 1071,
        'threesuperior'       => 551,
        'tilde'       => 500,
        'tonos'       => 500,
        'trademark'       => 947,
        'two'       => 626,
        'twoinferior'       => 551,
        'twosuperior'       => 551,
        'u'       => 685,
        'uacute'       => 685,
        'ubreve'       => 685,
        'ucircumflex'       => 685,
        'udieresis'       => 685,
        'ugrave'       => 685,
        'uhungarumlaut'       => 685,
        'umacron'       => 685,
        'underscore'       => 703,
        'underscoredbl'       => 703,
        'uni0326'       => 500,
        'uni1E9E'       => 791,
        'uni20B8'       => 634,
        'uni20B9'       => 634,
        'uni20BA'       => 634,
        'uni20BB'       => 736,
        'uni20BC'       => 988,
        'uni20BD'       => 650,
        'uni20BE'       => 786,
        'uni2120'       => 1128,
        'uogonek'       => 685,
        'upsilon'       => 604,
        'upsilondieresis'       => 604,
        'upsilondieresistonos'       => 604,
        'upsilontonos'       => 604,
        'uring'       => 685,
        'utilde'       => 685,
        'v'       => 612,
        'w'       => 933,
        'wacute'       => 933,
        'wcircumflex'       => 933,
        'wdieresis'       => 933,
        'wgrave'       => 933,
        'x'       => 583,
        'xi'       => 498,
        'y'       => 669,
        'yacute'       => 669,
        'ycircumflex'       => 669,
        'ydieresis'       => 669,
        'yen'       => 732,
        'ygrave'       => 669,
        'z'       => 517,
        'zacute'       => 517,
        'zcaron'       => 517,
        'zdotaccent'       => 517,
        'zero'       => 701,
        'zeroinferior'       => 551,
        'zerosuperior'       => 551,
        'zeta'       => 462,
    },
    'wxold' => { # HORIZ. WIDTH TABLE
        'space' => '253',                        # C+0x20 # U+0x0020
        'exclam' => '376',                       # C+0x21 # U+0x0021
        'quotedbl' => '509',                     # C+0x22 # U+0x0022
        'numbersign' => '703',                   # C+0x23 # U+0x0023
        'dollar' => '640',                       # C+0x24 # U+0x0024
        'percent' => '879',                      # C+0x25 # U+0x0025
        'ampersand' => '799',                    # C+0x26 # U+0x0026
        'quotesingle' => '269',                  # C+0x27 # U+0x0027
        'parenleft' => '446',                    # C+0x28 # U+0x0028
        'parenright' => '446',                   # C+0x29 # U+0x0029
        'asterisk' => '481',                     # C+0x2A # U+0x002A
        'plus' => '703',                         # C+0x2B # U+0x002B
        'comma' => '328',                        # C+0x2C # U+0x002C
        'hyphen' => '378',                       # C+0x2D # U+0x002D
        'period' => '328',                       # C+0x2E # U+0x002E
        'slash' => '471',                        # C+0x2F # U+0x002F
        'zero' => '701',                         # C+0x30 # U+0x0030
        'one' => '489',                          # C+0x31 # U+0x0031
        'two' => '626',                          # C+0x32 # U+0x0032
        'three' => '624',                        # C+0x33 # U+0x0033
        'four' => '649',                         # C+0x34 # U+0x0034
        'five' => '599',                         # C+0x35 # U+0x0035
        'six' => '647',                          # C+0x36 # U+0x0036
        'seven' => '566',                        # C+0x37 # U+0x0037
        'eight' => '676',                        # C+0x38 # U+0x0038
        'nine' => '647',                         # C+0x39 # U+0x0039
        'colon' => '367',                        # C+0x3A # U+0x003A
        'semicolon' => '367',                    # C+0x3B # U+0x003B
        'less' => '703',                         # C+0x3C # U+0x003C
        'equal' => '703',                        # C+0x3D # U+0x003D
        'greater' => '703',                      # C+0x3E # U+0x003E
        'question' => '548',                     # C+0x3F # U+0x003F
        'at' => '966',                           # C+0x40 # U+0x0040
        'A' => '758',                            # C+0x41 # U+0x0041
        'B' => '759',                            # C+0x42 # U+0x0042
        'C' => '715',                            # C+0x43 # U+0x0043
        'D' => '833',                            # C+0x44 # U+0x0044
        'E' => '721',                            # C+0x45 # U+0x0045
        'F' => '671',                            # C+0x46 # U+0x0046
        'G' => '807',                            # C+0x47 # U+0x0047
        'H' => '913',                            # C+0x48 # U+0x0048
        'I' => '450',                            # C+0x49 # U+0x0049
        'J' => '595',                            # C+0x4A # U+0x004A
        'K' => '816',                            # C+0x4B # U+0x004B
        'L' => '685',                            # C+0x4C # U+0x004C
        'M' => '1033',                           # C+0x4D # U+0x004D
        'N' => '829',                            # C+0x4E # U+0x004E
        'O' => '819',                            # C+0x4F # U+0x004F
        'P' => '706',                            # C+0x50 # U+0x0050
        'Q' => '819',                            # C+0x51 # U+0x0051
        'R' => '797',                            # C+0x52 # U+0x0052
        'S' => '652',                            # C+0x53 # U+0x0053
        'T' => '684',                            # C+0x54 # U+0x0054
        'U' => '833',                            # C+0x55 # U+0x0055
        'V' => '762',                            # C+0x56 # U+0x0056
        'W' => '1126',                           # C+0x57 # U+0x0057
        'X' => '802',                            # C+0x58 # U+0x0058
        'Y' => '731',                            # C+0x59 # U+0x0059
        'Z' => '689',                            # C+0x5A # U+0x005A
        'bracketleft' => '446',                  # C+0x5B # U+0x005B
        'backslash' => '471',                    # C+0x5C # U+0x005C
        'bracketright' => '446',                 # C+0x5D # U+0x005D
        'asciicircum' => '703',                  # C+0x5E # U+0x005E
        'underscore' => '703',                   # C+0x5F # U+0x005F
        'grave' => '500',                        # C+0x60 # U+0x0060
        'a' => '660',                            # C+0x61 # U+0x0061
        'b' => '648',                            # C+0x62 # U+0x0062
        'c' => '535',                            # C+0x63 # U+0x0063
        'd' => '662',                            # C+0x64 # U+0x0064
        'e' => '557',                            # C+0x65 # U+0x0065
        'f' => '380',                            # C+0x66 # U+0x0066
        'g' => '649',                            # C+0x67 # U+0x0067
        'h' => '675',                            # C+0x68 # U+0x0068
        'i' => '365',                            # C+0x69 # U+0x0069
        'j' => '364',                            # C+0x6A # U+0x006A
        'k' => '641',                            # C+0x6B # U+0x006B
        'l' => '354',                            # C+0x6C # U+0x006C
        'm' => '1001',                           # C+0x6D # U+0x006D
        'n' => '689',                            # C+0x6E # U+0x006E
        'o' => '635',                            # C+0x6F # U+0x006F
        'p' => '662',                            # C+0x70 # U+0x0070
        'q' => '649',                            # C+0x71 # U+0x0071
        'r' => '533',                            # C+0x72 # U+0x0072
        's' => '517',                            # C+0x73 # U+0x0073
        't' => '416',                            # C+0x74 # U+0x0074
        'u' => '685',                            # C+0x75 # U+0x0075
        'v' => '612',                            # C+0x76 # U+0x0076
        'w' => '933',                            # C+0x77 # U+0x0077
        'x' => '583',                            # C+0x78 # U+0x0078
        'y' => '669',                            # C+0x79 # U+0x0079
        'z' => '517',                            # C+0x7A # U+0x007A
        'braceleft' => '500',                    # C+0x7B # U+0x007B
        'bar' => '387',                          # C+0x7C # U+0x007C
        'braceright' => '500',                   # C+0x7D # U+0x007D
        'asciitilde' => '703',                   # C+0x7E # U+0x007E
        'bullet' => '437',                       # C+0x7F # U+0x2022
        'Euro' => '715',                         # C+0x80 # U+0x20AC
        'quotesinglbase' => '268',               # C+0x82 # U+0x201A
        'florin' => '579',                       # C+0x83 # U+0x0192
        'quotedblbase' => '519',                 # C+0x84 # U+0x201E
        'ellipsis' => '941',                     # C+0x85 # U+0x2026
        'dagger' => '481',                       # C+0x86 # U+0x2020
        'daggerdbl' => '481',                    # C+0x87 # U+0x2021
        'circumflex' => '500',                   # C+0x88 # U+0x02C6
        'perthousand' => '1316',                 # C+0x89 # U+0x2030
        'Scaron' => '648',                       # C+0x8A # U+0x0160
        'guilsinglleft' => '395',                # C+0x8B # U+0x2039
        'OE' => '1105',                          # C+0x8C # U+0x0152
        'Zcaron' => '689',                       # C+0x8E # U+0x017D
        'quoteleft' => '268',                    # C+0x91 # U+0x2018
        'quoteright' => '268',                   # C+0x92 # U+0x2019
        'quotedblleft' => '519',                 # C+0x93 # U+0x201C
        'quotedblright' => '519',                # C+0x94 # U+0x201D
        'endash' => '703',                       # C+0x96 # U+0x2013
        'emdash' => '927',                       # C+0x97 # U+0x2014
        'tilde' => '500',                        # C+0x98 # U+0x02DC
        'trademark' => '947',                    # C+0x99 # U+0x2122
        'scaron' => '517',                       # C+0x9A # U+0x0161
        'guilsinglright' => '395',               # C+0x9B # U+0x203A
        'oe' => '932',                           # C+0x9C # U+0x0153
        'zcaron' => '517',                       # C+0x9E # U+0x017E
        'Ydieresis' => '731',                    # C+0x9F # U+0x0178
        'exclamdown' => '376',                   # C+0xA1 # U+0x00A1
        'cent' => '605',                         # C+0xA2 # U+0x00A2
        'sterling' => '689',                     # C+0xA3 # U+0x00A3
        'currency' => '703',                     # C+0xA4 # U+0x00A4
        'yen' => '732',                          # C+0xA5 # U+0x00A5
        'brokenbar' => '387',                    # C+0xA6 # U+0x00A6
        'section' => '563',                      # C+0xA7 # U+0x00A7
        'dieresis' => '500',                     # C+0xA8 # U+0x00A8
        'copyright' => '941',                    # C+0xA9 # U+0x00A9
        'ordfeminine' => '551',                  # C+0xAA # U+0x00AA
        'guillemotleft' => '610',                # C+0xAB # U+0x00AB
        'logicalnot' => '703',                   # C+0xAC # U+0x00AC
        'registered' => '941',                   # C+0xAE # U+0x00AE
        'macron' => '500',                       # C+0xAF # U+0x00AF
        'degree' => '419',                       # C+0xB0 # U+0x00B0
        'plusminus' => '703',                    # C+0xB1 # U+0x00B1
        'twosuperior' => '551',                  # C+0xB2 # U+0x00B2
        'threesuperior' => '551',                # C+0xB3 # U+0x00B3
        'acute' => '500',                        # C+0xB4 # U+0x00B4
        'mu' => '669',                           # C+0xB5 # U+0x00B5
        'paragraph' => '622',                    # C+0xB6 # U+0x00B6
        'periodcentered' => '337',               # C+0xB7 # U+0x00B7
        'cedilla' => '500',                      # C+0xB8 # U+0x00B8
        'onesuperior' => '551',                  # C+0xB9 # U+0x00B9
        'ordmasculine' => '551',                 # C+0xBA # U+0x00BA
        'guillemotright' => '610',               # C+0xBB # U+0x00BB
        'onequarter' => '1071',                  # C+0xBC # U+0x00BC
        'onehalf' => '1071',                     # C+0xBD # U+0x00BD
        'threequarters' => '1071',               # C+0xBE # U+0x00BE
        'questiondown' => '548',                 # C+0xBF # U+0x00BF
        'Agrave' => '758',                       # C+0xC0 # U+0x00C0
        'Aacute' => '758',                       # C+0xC1 # U+0x00C1
        'Acircumflex' => '758',                  # C+0xC2 # U+0x00C2
        'Atilde' => '758',                       # C+0xC3 # U+0x00C3
        'Adieresis' => '758',                    # C+0xC4 # U+0x00C4
        'Aring' => '758',                        # C+0xC5 # U+0x00C5
        'AE' => '1074',                          # C+0xC6 # U+0x00C6
        'Ccedilla' => '715',                     # C+0xC7 # U+0x00C7
        'Egrave' => '721',                       # C+0xC8 # U+0x00C8
        'Eacute' => '721',                       # C+0xC9 # U+0x00C9
        'Ecircumflex' => '721',                  # C+0xCA # U+0x00CA
        'Edieresis' => '721',                    # C+0xCB # U+0x00CB
        'Igrave' => '445',                       # C+0xCC # U+0x00CC
        'Iacute' => '445',                       # C+0xCD # U+0x00CD
        'Icircumflex' => '445',                  # C+0xCE # U+0x00CE
        'Idieresis' => '450',                    # C+0xCF # U+0x00CF
        'Eth' => '833',                          # C+0xD0 # U+0x00D0
        'Ntilde' => '829',                       # C+0xD1 # U+0x00D1
        'Ograve' => '819',                       # C+0xD2 # U+0x00D2
        'Oacute' => '819',                       # C+0xD3 # U+0x00D3
        'Ocircumflex' => '819',                  # C+0xD4 # U+0x00D4
        'Otilde' => '819',                       # C+0xD5 # U+0x00D5
        'Odieresis' => '819',                    # C+0xD6 # U+0x00D6
        'multiply' => '703',                     # C+0xD7 # U+0x00D7
        'Oslash' => '819',                       # C+0xD8 # U+0x00D8
        'Ugrave' => '833',                       # C+0xD9 # U+0x00D9
        'Uacute' => '833',                       # C+0xDA # U+0x00DA
        'Ucircumflex' => '833',                  # C+0xDB # U+0x00DB
        'Udieresis' => '833',                    # C+0xDC # U+0x00DC
        'Yacute' => '731',                       # C+0xDD # U+0x00DD
        'Thorn' => '708',                        # C+0xDE # U+0x00DE
        'germandbls' => '655',                   # C+0xDF # U+0x00DF
        'agrave' => '660',                       # C+0xE0 # U+0x00E0
        'aacute' => '660',                       # C+0xE1 # U+0x00E1
        'acircumflex' => '660',                  # C+0xE2 # U+0x00E2
        'atilde' => '660',                       # C+0xE3 # U+0x00E3
        'adieresis' => '660',                    # C+0xE4 # U+0x00E4
        'aring' => '660',                        # C+0xE5 # U+0x00E5
        'ae' => '856',                           # C+0xE6 # U+0x00E6
        'ccedilla' => '535',                     # C+0xE7 # U+0x00E7
        'egrave' => '557',                       # C+0xE8 # U+0x00E8
        'eacute' => '557',                       # C+0xE9 # U+0x00E9
        'ecircumflex' => '557',                  # C+0xEA # U+0x00EA
        'edieresis' => '557',                    # C+0xEB # U+0x00EB
        'igrave' => '365',                       # C+0xEC # U+0x00EC
        'iacute' => '365',                       # C+0xED # U+0x00ED
        'icircumflex' => '365',                  # C+0xEE # U+0x00EE
        'idieresis' => '365',                    # C+0xEF # U+0x00EF
        'eth' => '637',                          # C+0xF0 # U+0x00F0
        'ntilde' => '689',                       # C+0xF1 # U+0x00F1
        'ograve' => '635',                       # C+0xF2 # U+0x00F2
        'oacute' => '635',                       # C+0xF3 # U+0x00F3
        'ocircumflex' => '635',                  # C+0xF4 # U+0x00F4
        'otilde' => '635',                       # C+0xF5 # U+0x00F5
        'odieresis' => '635',                    # C+0xF6 # U+0x00F6
        'divide' => '703',                       # C+0xF7 # U+0x00F7
        'oslash' => '635',                       # C+0xF8 # U+0x00F8
        'ugrave' => '685',                       # C+0xF9 # U+0x00F9
        'uacute' => '685',                       # C+0xFA # U+0x00FA
        'ucircumflex' => '685',                  # C+0xFB # U+0x00FB
        'udieresis' => '685',                    # C+0xFC # U+0x00FC
        'yacute' => '669',                       # C+0xFD # U+0x00FD
        'thorn' => '647',                        # C+0xFE # U+0x00FE
        'ydieresis' => '669',                    # C+0xFF # U+0x00FF
        'middot' => '337',                       # U+0x00B7
        'Amacron' => '758',                      # U+0x0100
        'amacron' => '660',                      # U+0x0101
        'Abreve' => '758',                       # U+0x0102
        'abreve' => '660',                       # U+0x0103
        'Aogonek' => '758',                      # U+0x0104
        'aogonek' => '660',                      # U+0x0105
        'Cacute' => '715',                       # U+0x0106
        'cacute' => '535',                       # U+0x0107
        'Ccircumflex' => '715',                  # U+0x0108
        'ccircumflex' => '535',                  # U+0x0109
        'Cdotaccent' => '715',                   # U+0x010A
        'cdotaccent' => '535',                   # U+0x010B
        'Ccaron' => '715',                       # U+0x010C
        'ccaron' => '535',                       # U+0x010D
        'Dcaron' => '833',                       # U+0x010E
        'dcaron' => '825',                       # U+0x010F
        'Dcroat' => '833',                       # U+0x0110
        'dcroat' => '662',                       # U+0x0111
        'Emacron' => '721',                      # U+0x0112
        'emacron' => '557',                      # U+0x0113
        'Ebreve' => '721',                       # U+0x0114
        'ebreve' => '557',                       # U+0x0115
        'Edotaccent' => '721',                   # U+0x0116
        'edotaccent' => '557',                   # U+0x0117
        'Eogonek' => '721',                      # U+0x0118
        'eogonek' => '557',                      # U+0x0119
        'Ecaron' => '721',                       # U+0x011A
        'ecaron' => '557',                       # U+0x011B
        'Gcircumflex' => '807',                  # U+0x011C
        'gcircumflex' => '649',                  # U+0x011D
        'Gbreve' => '807',                       # U+0x011E
        'gbreve' => '649',                       # U+0x011F
        'Gdotaccent' => '807',                   # U+0x0120
        'gdotaccent' => '649',                   # U+0x0121
        'Gcommaaccent' => '807',                 # U+0x0122
        'gcommaaccent' => '649',                 # U+0x0123
        'Hcircumflex' => '913',                  # U+0x0124
        'hcircumflex' => '675',                  # U+0x0125
        'Hbar' => '913',                         # U+0x0126
        'hbar' => '675',                         # U+0x0127
        'Itilde' => '450',                       # U+0x0128
        'itilde' => '365',                       # U+0x0129
        'Imacron' => '450',                      # U+0x012A
        'imacron' => '365',                      # U+0x012B
        'Ibreve' => '450',                       # U+0x012C
        'ibreve' => '365',                       # U+0x012D
        'Iogonek' => '450',                      # U+0x012E
        'iogonek' => '365',                      # U+0x012F
        'Idotaccent' => '450',                   # U+0x0130
        'dotlessi' => '365',                     # U+0x0131
        'IJ' => '996',                           # U+0x0132
        'ij' => '682',                           # U+0x0133
        'Jcircumflex' => '595',                  # U+0x0134
        'jcircumflex' => '364',                  # U+0x0135
        'Kcommaaccent' => '816',                 # U+0x0136
        'kcommaaccent' => '641',                 # U+0x0137
        'kgreenlandic' => '655',                 # U+0x0138
        'Lacute' => '685',                       # U+0x0139
        'lacute' => '354',                       # U+0x013A
        'Lcommaaccent' => '685',                 # U+0x013B
        'lcommaaccent' => '354',                 # U+0x013C
        'Lcaron' => '685',                       # U+0x013D
        'lcaron' => '511',                       # U+0x013E
        'Ldot' => '685',                         # U+0x013F
        'ldot' => '546',                         # U+0x0140
        'Lslash' => '685',                       # U+0x0141
        'lslash' => '354',                       # U+0x0142
        'Nacute' => '829',                       # U+0x0143
        'nacute' => '689',                       # U+0x0144
        'Ncommaaccent' => '829',                 # U+0x0145
        'ncommaaccent' => '689',                 # U+0x0146
        'Ncaron' => '829',                       # U+0x0147
        'ncaron' => '689',                       # U+0x0148
        'napostrophe' => '832',                  # U+0x0149
        'Eng' => '829',                          # U+0x014A
        'eng' => '677',                          # U+0x014B
        'Omacron' => '819',                      # U+0x014C
        'omacron' => '635',                      # U+0x014D
        'Obreve' => '819',                       # U+0x014E
        'obreve' => '635',                       # U+0x014F
        'Ohungarumlaut' => '819',                # U+0x0150
        'ohungarumlaut' => '635',                # U+0x0151
        'Racute' => '797',                       # U+0x0154
        'racute' => '533',                       # U+0x0155
        'Rcommaaccent' => '797',                 # U+0x0156
        'rcommaaccent' => '533',                 # U+0x0157
        'Rcaron' => '797',                       # U+0x0158
        'rcaron' => '533',                       # U+0x0159
        'Sacute' => '652',                       # U+0x015A
        'sacute' => '517',                       # U+0x015B
        'Scircumflex' => '652',                  # U+0x015C
        'scircumflex' => '517',                  # U+0x015D
        'Scedilla' => '652',                     # U+0x015E
        'scedilla' => '517',                     # U+0x015F
        'Tcommaaccent' => '684',                 # U+0x0162
        'tcommaaccent' => '416',                 # U+0x0163
        'Tcaron' => '684',                       # U+0x0164
        'tcaron' => '416',                       # U+0x0165
        'Tbar' => '684',                         # U+0x0166
        'tbar' => '416',                         # U+0x0167
        'Utilde' => '833',                       # U+0x0168
        'utilde' => '685',                       # U+0x0169
        'Umacron' => '833',                      # U+0x016A
        'umacron' => '685',                      # U+0x016B
        'Ubreve' => '833',                       # U+0x016C
        'ubreve' => '685',                       # U+0x016D
        'Uring' => '833',                        # U+0x016E
        'uring' => '685',                        # U+0x016F
        'Uhungarumlaut' => '833',                # U+0x0170
        'uhungarumlaut' => '685',                # U+0x0171
        'Uogonek' => '833',                      # U+0x0172
        'uogonek' => '685',                      # U+0x0173
        'Wcircumflex' => '1126',                 # U+0x0174
        'wcircumflex' => '933',                  # U+0x0175
        'Ycircumflex' => '731',                  # U+0x0176
        'ycircumflex' => '669',                  # U+0x0177
        'Zacute' => '689',                       # U+0x0179
        'zacute' => '517',                       # U+0x017A
        'Zdotaccent' => '689',                   # U+0x017B
        'zdotaccent' => '517',                   # U+0x017C
        'longs' => '361',                        # U+0x017F
        'Aringacute' => '758',                   # U+0x01FA
        'aringacute' => '660',                   # U+0x01FB
        'AEacute' => '1074',                     # U+0x01FC
        'aeacute' => '856',                      # U+0x01FD
        'Oslashacute' => '819',                  # U+0x01FE
        'oslashacute' => '635',                  # U+0x01FF
        'Scommaaccent' => '652',                 # U+0x0218
        'scommaaccent' => '517',                 # U+0x0219
        'caron' => '500',                        # U+0x02C7
        'breve' => '500',                        # U+0x02D8
        'dotaccent' => '500',                    # U+0x02D9
        'ring' => '500',                         # U+0x02DA
        'ogonek' => '500',                       # U+0x02DB
        'hungarumlaut' => '500',                 # U+0x02DD
        'dblgravecmb' => '500',                  # U+0x030F
        'tonos' => '500',                        # U+0x0384
        'dieresistonos' => '500',                # U+0x0385
        'Alphatonos' => '758',                   # U+0x0386
        'anoteleia' => '367',                    # U+0x0387
        'Epsilontonos' => '880',                 # U+0x0388
        'Etatonos' => '1072',                    # U+0x0389
        'Iotatonos' => '609',                    # U+0x038A
        'Omicrontonos' => '922',                 # U+0x038C
        'Upsilontonos' => '935',                 # U+0x038E
        'Omegatonos' => '960',                   # U+0x038F
        'iotadieresistonos' => '345',            # U+0x0390
        'Alpha' => '758',                        # U+0x0391
        'Beta' => '759',                         # U+0x0392
        'Gamma' => '655',                        # U+0x0393
        'Delta' => '743',                        # U+0x0394
        'Epsilon' => '721',                      # U+0x0395
        'Zeta' => '689',                         # U+0x0396
        'Eta' => '913',                          # U+0x0397
        'Theta' => '822',                        # U+0x0398
        'Iota' => '450',                         # U+0x0399
        'Kappa' => '816',                        # U+0x039A
        'Lambda' => '752',                       # U+0x039B
        'Mu' => '1033',                          # U+0x039C
        'Nu' => '829',                           # U+0x039D
        'Xi' => '766',                           # U+0x039E
        'Omicron' => '819',                      # U+0x039F
        'Pi' => '900',                           # U+0x03A0
        'Rho' => '706',                          # U+0x03A1
        'Sigma' => '679',                        # U+0x03A3
        'Tau' => '684',                          # U+0x03A4
        'Upsilon' => '731',                      # U+0x03A5
        'Phi' => '911',                          # U+0x03A6
        'Chi' => '802',                          # U+0x03A7
        'Psi' => '1011',                         # U+0x03A8
        'Omega' => '877',                        # U+0x03A9
        'Iotadieresis' => '450',                 # U+0x03AA
        'Upsilondieresis' => '731',              # U+0x03AB
        'alphatonos' => '679',                   # U+0x03AC
        'epsilontonos' => '535',                 # U+0x03AD
        'etatonos' => '665',                     # U+0x03AE
        'iotatonos' => '345',                    # U+0x03AF
        'upsilondieresistonos' => '604',         # U+0x03B0
        'alpha' => '679',                        # U+0x03B1
        'beta' => '658',                         # U+0x03B2
        'gamma' => '570',                        # U+0x03B3
        'delta' => '635',                        # U+0x03B4
        'epsilon' => '535',                      # U+0x03B5
        'zeta' => '462',                         # U+0x03B6
        'eta' => '665',                          # U+0x03B7
        'theta' => '640',                        # U+0x03B8
        'iota' => '345',                         # U+0x03B9
        'kappa' => '655',                        # U+0x03BA
        'lambda' => '527',                       # U+0x03BB
        'nu' => '561',                           # U+0x03BD
        'xi' => '498',                           # U+0x03BE
        'omicron' => '635',                      # U+0x03BF
        'pi' => '659',                           # U+0x03C0
        'rho' => '645',                          # U+0x03C1
        'sigma1' => '513',                       # U+0x03C2
        'sigma' => '669',                        # U+0x03C3
        'tau' => '485',                          # U+0x03C4
        'upsilon' => '604',                      # U+0x03C5
        'phi' => '830',                          # U+0x03C6
        'chi' => '566',                          # U+0x03C7
        'psi' => '857',                          # U+0x03C8
        'omega' => '804',                        # U+0x03C9
        'iotadieresis' => '345',                 # U+0x03CA
        'upsilondieresis' => '604',              # U+0x03CB
        'omicrontonos' => '635',                 # U+0x03CC
        'upsilontonos' => '604',                 # U+0x03CD
        'omegatonos' => '804',                   # U+0x03CE
        'afii10023' => '721',                    # U+0x0401
        'afii10051' => '883',                    # U+0x0402
        'afii10052' => '655',                    # U+0x0403
        'afii10053' => '730',                    # U+0x0404
        'afii10054' => '652',                    # U+0x0405
        'afii10055' => '450',                    # U+0x0406
        'afii10056' => '450',                    # U+0x0407
        'afii10057' => '595',                    # U+0x0408
        'afii10058' => '1112',                   # U+0x0409
        'afii10059' => '1184',                   # U+0x040A
        'afii10060' => '935',                    # U+0x040B
        'afii10061' => '794',                    # U+0x040C
        'afii10062' => '712',                    # U+0x040E
        'afii10145' => '901',                    # U+0x040F
        'afii10017' => '758',                    # U+0x0410
        'afii10018' => '743',                    # U+0x0411
        'afii10019' => '759',                    # U+0x0412
        'afii10020' => '655',                    # U+0x0413
        'afii10021' => '800',                    # U+0x0414
        'afii10022' => '721',                    # U+0x0415
        'afii10024' => '1127',                   # U+0x0416
        'afii10025' => '684',                    # U+0x0417
        'afii10026' => '921',                    # U+0x0418
        'afii10027' => '921',                    # U+0x0419
        'afii10028' => '794',                    # U+0x041A
        'afii10029' => '832',                    # U+0x041B
        'afii10030' => '1033',                   # U+0x041C
        'afii10031' => '913',                    # U+0x041D
        'afii10032' => '819',                    # U+0x041E
        'afii10033' => '900',                    # U+0x041F
        'afii10034' => '706',                    # U+0x0420
        'afii10035' => '715',                    # U+0x0421
        'afii10036' => '684',                    # U+0x0422
        'afii10037' => '712',                    # U+0x0423
        'afii10038' => '911',                    # U+0x0424
        'afii10039' => '802',                    # U+0x0425
        'afii10040' => '901',                    # U+0x0426
        'afii10041' => '832',                    # U+0x0427
        'afii10042' => '1283',                   # U+0x0428
        'afii10043' => '1284',                   # U+0x0429
        'afii10044' => '855',                    # U+0x042A
        'afii10045' => '1106',                   # U+0x042B
        'afii10046' => '726',                    # U+0x042C
        'afii10047' => '729',                    # U+0x042D
        'afii10048' => '1183',                   # U+0x042E
        'afii10049' => '803',                    # U+0x042F
        'afii10065' => '660',                    # U+0x0430
        'afii10066' => '627',                    # U+0x0431
        'afii10067' => '598',                    # U+0x0432
        'afii10068' => '520',                    # U+0x0433
        'afii10069' => '620',                    # U+0x0434
        'afii10070' => '557',                    # U+0x0435
        'afii10072' => '1091',                   # U+0x0436
        'afii10073' => '539',                    # U+0x0437
        'afii10074' => '685',                    # U+0x0438
        'afii10075' => '685',                    # U+0x0439
        'afii10076' => '646',                    # U+0x043A
        'afii10077' => '647',                    # U+0x043B
        'afii10078' => '875',                    # U+0x043C
        'afii10079' => '688',                    # U+0x043D
        'afii10080' => '635',                    # U+0x043E
        'afii10081' => '689',                    # U+0x043F
        'afii10082' => '662',                    # U+0x0440
        'afii10083' => '535',                    # U+0x0441
        'afii10084' => '1001',                   # U+0x0442
        'afii10085' => '669',                    # U+0x0443
        'afii10086' => '886',                    # U+0x0444
        'afii10087' => '583',                    # U+0x0445
        'afii10088' => '685',                    # U+0x0446
        'afii10089' => '656',                    # U+0x0447
        'afii10090' => '982',                    # U+0x0448
        'afii10091' => '982',                    # U+0x0449
        'afii10092' => '668',                    # U+0x044A
        'afii10093' => '925',                    # U+0x044B
        'afii10094' => '614',                    # U+0x044C
        'afii10095' => '539',                    # U+0x044D
        'afii10096' => '919',                    # U+0x044E
        'afii10097' => '642',                    # U+0x044F
        'afii10071' => '557',                    # U+0x0451
        'afii10099' => '663',                    # U+0x0452
        'afii10100' => '520',                    # U+0x0453
        'afii10101' => '535',                    # U+0x0454
        'afii10102' => '517',                    # U+0x0455
        'afii10103' => '365',                    # U+0x0456
        'afii10104' => '365',                    # U+0x0457
        'afii10105' => '364',                    # U+0x0458
        'afii10106' => '895',                    # U+0x0459
        'afii10107' => '937',                    # U+0x045A
        'afii10108' => '675',                    # U+0x045B
        'afii10109' => '646',                    # U+0x045C
        'afii10110' => '669',                    # U+0x045E
        'afii10193' => '685',                    # U+0x045F
        'afii10050' => '645',                    # U+0x0490
        'afii10098' => '510',                    # U+0x0491
        'Wgrave' => '1126',                      # U+0x1E80
        'wgrave' => '933',                       # U+0x1E81
        'Wacute' => '1126',                      # U+0x1E82
        'wacute' => '933',                       # U+0x1E83
        'Wdieresis' => '1126',                   # U+0x1E84
        'wdieresis' => '933',                    # U+0x1E85
        'Ygrave' => '731',                       # U+0x1EF2
        'ygrave' => '669',                       # U+0x1EF3
        'afii00208' => '927',                    # U+0x2015
        'underscoredbl' => '703',                # U+0x2017
        'quotereversed' => '268',                # U+0x201B
        'minute' => '321',                       # U+0x2032
        'second' => '532',                       # U+0x2033
        'exclamdbl' => '664',                    # U+0x203C
        'fraction' => '94',                      # U+0x2044
        'foursuperior' => '551',                 # U+0x2074
        'fivesuperior' => '551',                 # U+0x2075
        'sevensuperior' => '551',                # U+0x2077
        'eightsuperior' => '551',                # U+0x2078
        'nsuperior' => '551',                    # U+0x207F
        'franc' => '689',                        # U+0x20A3
        'lira' => '689',                         # U+0x20A4
        'peseta' => '1355',                      # U+0x20A7
        'afii61248' => '879',                    # U+0x2105
        'afii61289' => '323',                    # U+0x2113
        'afii61352' => '1401',                   # U+0x2116
        'estimated' => '649',                    # U+0x212E
        'oneeighth' => '1071',                   # U+0x215B
        'threeeighths' => '1071',                # U+0x215C
        'fiveeighths' => '1071',                 # U+0x215D
        'seveneighths' => '1071',                # U+0x215E
        'partialdiff' => '646',                  # U+0x2202
        'product' => '932',                      # U+0x220F
        'summation' => '729',                    # U+0x2211
        'minus' => '703',                        # U+0x2212
        'radical' => '703',                      # U+0x221A
        'infinity' => '798',                     # U+0x221E
        'integral' => '627',                     # U+0x222B
        'approxequal' => '703',                  # U+0x2248
        'notequal' => '703',                     # U+0x2260
        'lessequal' => '703',                    # U+0x2264
        'greaterequal' => '703',                 # U+0x2265
        'H22073' => '604',                       # U+0x25A1
        'H18543' => '354',                       # U+0x25AA
        'H18551' => '354',                       # U+0x25AB
        'lozenge' => '717',                      # U+0x25CA
        'H18533' => '604',                       # U+0x25CF
        'openbullet' => '354',                   # U+0x25E6
        'commaaccent' => '500',                  # U+0xF6C3
        'Acute' => '500',                        # U+0xF6C9
        'Caron' => '500',                        # U+0xF6CA
        'Dieresis' => '500',                     # U+0xF6CB
        'Grave' => '500',                        # U+0xF6CE
        'Hungarumlaut' => '500',                 # U+0xF6CF
        'radicalex' => '703',                    # U+0xF8E5
        'fi' => '701',                           # U+0xFB01
        'fl' => '720',                           # U+0xFB02
    }, # HORIZ. WIDTH TABLE
} };

1;
